# PyNumStim

**Python library to create symbolic number and arithmetic stimuli for psychological experiments**

[![GitHub license](https://img.shields.io/github/license/lindemann09/PyNumStim)](https://github.com/lindemann09/PyNumStim/blob/master/LICENSE)
[![Python Version](https://img.shields.io/pypi/pyversions/pynumstim?style=flat)](https://www.python.org)
[![PyPI](https://img.shields.io/pypi/v/pynumstim?style=flat)](https://pypi.org/project/pynumstim/)

(c) Oliver Lindemann (lindemann@cognitive-psychology.eu)

Project homepage: https://github.com/lindemann09/PyNumStim

## Install via pip

```
pip install pynumstim
```


## Requirements

* Python >= 3.10
* dvipng


